import math
import os
import sys 

def bytestoint(bytes):
	return ord(bytes[0]) + (ord(bytes[1]) << 8) + (ord(bytes[2]) << 16) + (ord(bytes[3]) << 24) 

if (len(sys.argv) != 2):
	print("Usage: rsccreate <resource file>")
	print("You will need to have the directory in your current working directory")

	exit()
	
rscfile = sys.argv[1]
	
hfile = open(rscfile, "rb")
file = hfile.read()

offset = 0

#check file header
header0 = "\x7B\x01\x0C\x00\x00\x00\x7F\xFF\xFF\xFF\x02\x00\x00\x00"
if file[offset:offset+14] != header0:
		print("Header 0 mismatch")
		exit()
offset+=14

#get offset of end of header block
endoffset = bytestoint(file[offset:offset+4]) + 22
offset+=4
		
#check remaining padding
padding0 = "\x11\x00\x00\x00"
if file[offset:offset+4] != padding0:
	print("Padding 0 mismatch")
	exit()	
offset+=4

#process header		
filecount = 0
while(offset < endoffset):
	filecount+=1
	
	#check header padding
	header1 = "\x48\x00\x65\x80"
	if file[offset:offset+4] != header1:
		print("Header 1 mismatch")
		break
	offset+=4
	
	#get filenamename size
	#namesize = ord(file[offset])
	namesize = bytestoint(file[offset:offset+4])
	offset+=4
	
	#get filename
	filename = file[offset:offset+namesize]
	offset += int(math.ceil(namesize/4.0)*4)
	
	#check padding	
	padding1 = "\x4a\x00\x66\x00"
	if file[offset:offset+4] != padding1:
		print("Padding 1 mismatch")
		break
	offset+=4
		
	#get file offset
	fileoffset = bytestoint(file[offset:offset+4])
	offset+=4
	
	#check padding
	padding2 = "\x4a\x00\x68\x00"
	if file[offset:offset+4] != padding2:
		print("Padding 2 mismatch")
		break
	offset+=4
	
	#get file size
	filesize = bytestoint(file[offset:offset+4])
	offset+=4
	
	#print file name, start offset, and size 
	print(filename + " " + str(fileoffset) + " " + str(filesize))
	
	#create a folder for all the files
	if not os.path.exists(os.getcwd() + "\\" + rscfile.replace(".rsc","")):
		os.makedirs(os.getcwd() + "\\" + rscfile.replace(".rsc",""))
	
	#write each file to the folder
	file2 = open(os.getcwd() + "\\" + rscfile.replace(".rsc","") + "\\" + filename, "wb+")
	file2.write(file[endoffset+fileoffset:endoffset+fileoffset+filesize])
	
print("\nFiles: " + str(filecount))


